@@ -21,7 +21,6 @@ hidden_imports = [
     "ics.structures.op_eth_general_settings",
     "ics.structures.srad_gptp_settings_s",
     "ics.structures.srad_gptp_and_tap_settings_s",
-    "ics.structures.hw_eth_settings",
     "ics.structures.op_eth_settings",
     "ics.structures.ethernet_settings",
     "ics.structures.ethernet_settings2",
@@ -82,7 +81,6 @@ hidden_imports = [
     "ics.structures.s_cyan_settings",
     "ics.structures.svcan3_settings",
     "ics.structures.svcan4_settings",
-    "ics.structures.svcanrf_settings",
     "ics.structures.secu_settings",
     "ics.structures.s_pendant_settings",
     "ics.structures.sievb_settings",
@@ -151,6 +149,9 @@ hidden_imports = [
     "ics.structures.sradbms_settings",
     "ics.structures.srad_comet_settings",
     "ics.structures.srad_comet3_settings",
+    "ics.structures.srad_gigastar2_settings",
+    "ics.structures.srad_moon_t1_s_settings",
+    "ics.structures.s_neo_vi_connect_settings",
     "ics.structures.global_settings",
     "ics.structures.s_device_settings",
     "ics.structures.st_cm_iso157652_tx_message",
