@@ -21,7 +21,6 @@ __all__ = [
     "op_eth_general_settings",
     "srad_gptp_settings_s",
     "srad_gptp_and_tap_settings_s",
-    "hw_eth_settings",
     "op_eth_settings",
     "ethernet_settings",
     "ethernet_settings2",
@@ -82,7 +81,6 @@ __all__ = [
     "s_cyan_settings",
     "svcan3_settings",
     "svcan4_settings",
-    "svcanrf_settings",
     "secu_settings",
     "s_pendant_settings",
     "sievb_settings",
@@ -151,6 +149,9 @@ __all__ = [
     "sradbms_settings",
     "srad_comet_settings",
     "srad_comet3_settings",
+    "srad_gigastar2_settings",
+    "srad_moon_t1_s_settings",
+    "s_neo_vi_connect_settings",
     "global_settings",
     "s_device_settings",
     "st_cm_iso157652_tx_message",
