@@ -8,7 +8,7 @@ extern "C"
 #endif
 
     int initialize_exceptions(PyObject* module);
-    PyObject* _set_ics_exception(PyObject* exception, char* msg, const char* func_name);
+    PyObject* _set_ics_exception(PyObject* exception, const char* msg, const char* func_name);
 #define set_ics_exception(exception, msg) _set_ics_exception(exception, msg, __FUNCTION__);
 
     PyObject* exception_argument_error(void);
