@@ -5,34 +5,6 @@
 static PyObject* IcsArgumentError = NULL;
 static PyObject* IcsRuntimeError = NULL;
 
-char* pyics_base36enc(int sn)
-{
-    char* result = NULL;
-#if PY_MAJOR_VERSION >= 3
-    PyObject* name = PyUnicode_FromString("ics.ics");
-#else
-    PyObject* name = PyString_FromString("ics.ics");
-#endif
-    PyObject* module = PyImport_Import(name);
-    PyObject* dict = PyModule_GetDict(module);
-    PyObject* base36enc = PyDict_GetItemString(dict, "base36enc");
-    if (PyCallable_Check(base36enc)) {
-        PyObject* return_value = PyObject_CallFunction(base36enc, "i", sn);
-        if (return_value == NULL) {
-            // We failed for some reason...
-            PyErr_Print();
-            Py_DECREF(module);
-            Py_DECREF(name);
-            return NULL;
-        } else {
-            return PyUniStr_AsStrOrUTF8(return_value);
-        }
-    }
-    Py_DECREF(module);
-    Py_DECREF(name);
-    return "";
-}
-
 int initialize_exceptions(PyObject* module)
 {
     if (!module && IcsArgumentError && IcsRuntimeError) {
@@ -55,7 +27,7 @@ int initialize_exceptions(PyObject* module)
     return 1;
 }
 
-PyObject* _set_ics_exception(PyObject* exception, char* msg, const char* func_name)
+PyObject* _set_ics_exception(PyObject* exception, const char* msg, const char* func_name)
 {
     std::stringstream ss;
     std::string function = std::string(func_name);
